@@ -13,6 +13,6 @@ fn main() {
 
     if let Ok(shell) = matches.value_of_t::<clap_complete_command::Shell>("completion") {
         let mut command = build_cli();
-        shell.generate(&mut command, env!("CARGO_PKG_NAME"), &mut std::io::stdout());
+        shell.generate(&mut command, &mut std::io::stdout());
     }
 }
